==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-solvers/Operators/TSFSimpleBlockOpDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
//
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
//
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
//
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov)
//
// **********************************************************************/
 /* @HEADER@ */

#ifndef TSFSIMPLEBLOCKOP_DECL_HPP
#define TSFSIMPLEBLOCKOP_DECL_HPP


#include "SundanceDefs.hpp"
#include "Teuchos_Array.hpp"
#include "TSFBlockOperatorBaseDecl.hpp"
#include "TSFLinearOperatorDecl.hpp"
#include "TSFSimplifiedLinearOpBaseDecl.hpp"



namespace TSFExtended
{
using namespace Teuchos;

/**
 * Array-based block operator
 *
 * @author Kevin Long (kevin.long@ttu.edu)
 */
template <class Scalar>
class SimpleBlockOp : public SimplifiedLinearOpWithSpaces<Scalar>,
                      public SetableBlockOperatorBase<Scalar>
{
public:
  /** */
  SimpleBlockOp(const VectorSpace<Scalar>& domain,
    const VectorSpace<Scalar>& range);

  /** */
  int numBlockRows() const  ;

  /** */
  int numBlockCols() const ;

  /** */
  const LinearOperator<Scalar>& getBlock(int i, int j) const ;

  /** */
  LinearOperator<Scalar> getNonconstBlock(int i, int j) ;

  /** */
  void setBlock(int i, int j, const LinearOperator<Scalar>& Aij) ; 

  /** */
  void applyOp(const Thyra::ETransp M_trans,
    const Vector<Scalar>& in,
    Vector<Scalar> out) const ;

private:
  Array<Array<LinearOperator<Scalar> > > blocks_;

}; 


/** \relates SimpleBlockOp Nonmember function to create a SimpleBlockOp */
template <class Scalar>
LinearOperator<Scalar> makeBlockOperator(
  const VectorSpace<Scalar>& domain,
  const VectorSpace<Scalar>& range
  );





}

#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-solvers/Operators/TSFSimpleBlockOpDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
//
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
//
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
//
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov)
//
// **********************************************************************/
 /* @HEADER@ */

#ifndef TSFSIMPLEBLOCKOP_DECL_HPP
#define TSFSIMPLEBLOCKOP_DECL_HPP


#include "SundanceDefs.hpp"
#include "Teuchos_Array.hpp"
#include "TSFBlockOperatorBaseDecl.hpp"
#include "TSFLinearOperatorDecl.hpp"
#include "TSFSimplifiedLinearOpBaseDecl.hpp"



namespace TSFExtended
{
using namespace Teuchos;

/**
 * Array-based block operator
 *
 * @author Kevin Long (kevin.long@ttu.edu)
 */
template <class Scalar>
class SimpleBlockOp : public SimplifiedLinearOpWithSpaces<Scalar>,
                      public SetableBlockOperatorBase<Scalar>
{
public:
  /** */
  SimpleBlockOp(const VectorSpace<Scalar>& domain,
    const VectorSpace<Scalar>& range);

  /** */
  int numBlockRows() const  ;

  /** */
  int numBlockCols() const ;

  /** */
  const LinearOperator<Scalar>& getBlock(int i, int j) const ;

  /** */
  LinearOperator<Scalar> getNonconstBlock(int i, int j) ;

  /** */
  void setBlock(int i, int j, const LinearOperator<Scalar>& Aij) ; 

  /** */
  void applyOp(const Thyra::EOpTransp M_trans,
    const Vector<Scalar>& in,
    Vector<Scalar> out) const ;

private:
  Array<Array<LinearOperator<Scalar> > > blocks_;

}; 


/** \relates SimpleBlockOp Nonmember function to create a SimpleBlockOp */
template <class Scalar>
LinearOperator<Scalar> makeBlockOperator(
  const VectorSpace<Scalar>& domain,
  const VectorSpace<Scalar>& range
  );





}

#endif
